@@ -1,10 +1,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    from celery.utils.compat import OrderedDict
+from celery.utils.compat import OrderedDict
 
 
 class BaseModel(object):
@@ -25,11 +22,12 @@ class WorkersModel(BaseModel):
 
         state = self.app.state
         for workername, stat in sorted(state.stats.iteritems()):
+            pool = stat.get('pool') or {}
             self.workers[workername] = dict(
                     status=(workername in state.ping),
-                    concurrency=stat['pool']['max-concurrency'] if stat['pool'] else None,
+                    concurrency=pool.get('max-concurrency'),
                     completed_tasks=sum(stat['total'].itervalues()),
-                    running_tasks=len(state.active_tasks.get(workername, [])),
+                    running_tasks=state.active_tasks.get(workername, []),
                     queues=map(lambda x: x['name'],
                                state.active_queues.get(workername, [])),
                     )
@@ -101,15 +99,17 @@ class TaskModel(BaseModel):
             return None
 
     @classmethod
-    def iter_tasks(cls, app, limit=None, type=None, worker=None):
+    def iter_tasks(cls, app, limit=None, type=None, worker=None, state=None):
         i = 0
-        state = app.events.state
-        for uuid, task in state._sort_tasks_by_time(
-                state.itertasks()):
+        events_state = app.events.state
+        for uuid, task in events_state._sort_tasks_by_time(
+                events_state.itertasks()):
             if type and task.name != type:
                 continue
             if worker and task.worker.hostname != worker:
                 continue
+            if state and task.state != state:
+                continue
             yield uuid, task
             i += 1
             if i == limit:
