@@ -12,8 +12,12 @@ from .views.tasks import (
         TasksView,
         )
 
+from .views import auth
+
 from .api import events
 from .api import control
+from .api import tasks
+from .api import workers
 
 from .views.update import (
         UpdateWorkers,
@@ -37,18 +41,24 @@ handlers = [
     (r"/worker/(.+)", WorkerView),
     (r"/task/(.+)", TaskView),
     (r"/tasks", TasksView),
-    # API
+    # Worker API
+    (r"/api/workers", workers.ListWorkers),
     (r"/api/worker/shutdown/(.+)", control.WorkerShutDown),
     (r"/api/worker/pool/restart/(.+)", control.WorkerPoolRestart),
     (r"/api/worker/pool/grow/(.+)", control.WorkerPoolGrow),
     (r"/api/worker/pool/shrink/(.+)", control.WorkerPoolShrink),
     (r"/api/worker/pool/autoscale/(.+)", control.WorkerPoolAutoscale),
     (r"/api/worker/queue/add-consumer/(.+)", control.WorkerQueueAddConsumer),
-    (r"/api/worker/queue/cancel-consumer/(.+)", control.WorkerQueueCancelConsumer),
+    (r"/api/worker/queue/cancel-consumer/(.+)",
+        control.WorkerQueueCancelConsumer),
+    # Task API
+    (r"/api/tasks", tasks.ListTasks),
+    (r"/api/task/async-apply/(.+)", tasks.TaskAsyncApply),
+    (r"/api/task/result/(.+)", tasks.TaskResult),
     (r"/api/task/timeout/(.+)", control.TaskTimout),
     (r"/api/task/rate-limit/(.+)", control.TaskRateLimit),
     (r"/api/task/revoke/(.+)", control.TaskRevoke),
-    # WebSocket API
+    # Events WebSocket API
     (r"/api/task/events/task-sent/(.*)", events.TaskSent),
     (r"/api/task/events/task-received/(.*)", events.TaskReceived),
     (r"/api/task/events/task-started/(.*)", events.TaskStarted),
@@ -65,6 +75,10 @@ handlers = [
     # Static
     (r"/static/(.*)", StaticFileHandler,
                         {"path": APP_SETTINGS['static_path']}),
+    # Auth
+    (r"/login", auth.LoginHandler),
+    (r"/logout", auth.LogoutHandler),
+
     # Error
     (r".*", NotFoundErrorHandler),
 ]
